@@ -1,6 +1,6 @@
 """Top-level module for regexapp.
 
-- support TextPattern, ElementPattern, LinePattern, BlockPattern, and PatternBuilder
+- support TextPattern, ElementPattern, LinePattern, MultilinePattern, and PatternBuilder
 - support predefine pattern reference on system_references.yaml
 - allow end-user to customize pattern on /home/.regexapp/user_references.yaml
 - allow end-user to generate test script or pattern on GUI application.
@@ -13,14 +13,14 @@ from regexapp.collection import TextPattern
 from regexapp.collection import ElementPattern
 from regexapp.collection import LinePattern
 from regexapp.collection import PatternBuilder
-from regexapp.collection import BlockPattern
+from regexapp.collection import MultilinePattern
 from regexapp.collection import PatternReference
 from regexapp.core import RegexBuilder
 from regexapp.core import DynamicGenTestScript
 from regexapp.core import add_reference
 from regexapp.core import remove_reference
 
-__version__ = '0.1.2'
+__version__ = '0.2.0'
 version = __version__
 __edition__ = 'Community'
 edition = __edition__
@@ -29,7 +29,7 @@ __all__ = [
     'TextPattern',
     'ElementPattern',
     'LinePattern',
-    'BlockPattern',
+    'MultilinePattern',
     'PatternBuilder',
     'PatternReference',
     'RegexBuilder',
