@@ -162,28 +162,80 @@ class Application:
     Attributes
     ----------
     root (tkinter.Tk): a top tkinter app.
-    content (Content): a Content instance.
+
+    panedwindow (ttk.Panedwindow): a panedwindow for main layout.
+    text_frame (ttk.Frame): a frame to contain test data component.
+    entry_frame (tk.Frame): a frame to contain any action button such as
+            open, paste, build, snippet, unittest, pytest, ...
+    result_frame (tk.Frame): a frame to contain test result component.
+    save_as_btn (ttk.Button): a Save As button.
+    copy_text_btn (ttk.Button): a Copy Text button.
+
+    test_data (str): a test data
+
+    radio_line_or_multiline_btn_var (tk.StringVar): a variable for radio button
+            Default is multiline.
+    prepended_ws_var (tk.BooleanVar): a variable for prepended_ws checkbox.
+            Default is False
+    appended_ws_var (tk.BooleanVar): a variable for appended_ws checkbox.
+            Default is False.
+    ignore_case_var (tk.BooleanVar): a variable for ignore_case checkbox.
+            Default is False
+    test_name_var (tk.StringVar): a variable for test_name textbox.
+            Default is empty string.
+    test_cls_name_var (tk.StringVar): a variable for test_cls_name_var.
+            Default is TestDynamicGenTestScript.
+    is_minimal_var (tk.BooleanVar): a variable for is_minimal checkbox.
+            Default is True.
+    max_words_var (tk.IntVar): a variable for max_words textbox.
+            Default is 6.
+    filename_var (tk.StringVar): a variable for filename textbox.
+            Default is empty string.
+    author_var (tk.StringVar): a variable for author textbox.
+            Default is empty string.
+    email_var (tk.StringVar): a variable for email textbox.  Default is empty string.
+    company_var (tk.StringVar): a variable for company textbox.  Default is empty string.
+
+    new_pattern_name_var (tk.StringVar): a variable for creating new pattern
+            reference.  Default is empty string.
+
+    textarea (tk.Text): a TextArea component for test data.
+    result_textarea (tk.Text): a TextArea component for test result.
+    line_radio_btn (tk.RadioButton): a selection for enabling LinePattern.
+    multiline_radio_btn (tk.RadioButton): a selection for enabling MultilinePattern.
 
     Methods
     -------
-    build_menu() -> None
-    run() -> None
+    get_pattern_args() -> dict
+    get_builder_args() -> dict
+    set_default_setting() -> None
+    Application.get_textarea(node) -> str
+    set_textarea(node, data, title='') -> None
+    set_title(node=None, title='') -> None
     callback_file_open() -> None
     callback_file_exit() -> None
     callback_help_documentation() -> None
     callback_help_view_licenses() -> None
     callback_help_about() -> None
+    callback_preferences_settings() -> None
+    callback_preferences_system_reference() -> None
+    callback_preferences_user_reference() -> None
+    build_menu() -> None
+    build_frame() -> None
+    build_textarea() -> None
+    build_entry() -> None
+    build_result() -> None
+    run() -> None
     """
 
     browser = webbrowser
 
     def __init__(self):
-        self._base_title = 'Regex GUI'
+        self._base_title = 'Regexapp {}'.format(edition)
         self.root = tk.Tk()
-        self.root.geometry('900x600+100+100')
+        self.root.geometry('940x600+100+100')
         self.root.minsize(200, 200)
         self.root.option_add('*tearOff', False)
-        self.content = None
 
         self.panedwindow = None
         self.text_frame = None
@@ -194,10 +246,8 @@ class Application:
 
         self.test_data = None
 
-        self.radio_line_or_block_btn_var = tk.StringVar()
-        self.radio_line_or_block_btn_var.set('block')
-        self.used_space_var = tk.BooleanVar()
-        self.used_space_var.set(True)
+        self.radio_line_or_multiline_btn_var = tk.StringVar()
+        self.radio_line_or_multiline_btn_var.set('multiline')
         self.prepended_ws_var = tk.BooleanVar()
         self.appended_ws_var = tk.BooleanVar()
         self.ignore_case_var = tk.BooleanVar()
@@ -218,7 +268,7 @@ class Application:
         self.textarea = None
         self.result_textarea = None
         self.line_radio_btn = None
-        self.block_radio_btn = None
+        self.multiline_radio_btn = None
 
         self.set_title()
         self.build_menu()
@@ -230,11 +280,10 @@ class Application:
     def get_pattern_args(self):
         """return arguments of RegexBuilder class"""
         result = dict(
-            used_space=self.used_space_var.get(),
             ignore_case=self.ignore_case_var.get(),
             prepended_ws=self.prepended_ws_var.get(),
             appended_ws=self.appended_ws_var.get(),
-            is_line=self.radio_line_or_block_btn_var.get() == 'line'
+            is_line=self.radio_line_or_multiline_btn_var.get() == 'line'
         )
         return result
 
@@ -254,7 +303,6 @@ class Application:
 
     def set_default_setting(self):
         """reset to default setting"""
-        self.used_space_var.set(True)
         self.prepended_ws_var.set(False)
         self.appended_ws_var.set(False)
         self.ignore_case_var.set(False)
@@ -321,8 +369,7 @@ class Application:
     def callback_file_open(self):
         """Callback for Menu File > Open."""
         filetypes = [
-            ('Text Files (*.txt)', '*.txt'),
-            ('All Dot Files (*.*)', '*.*'),
+            ('Text Files', '.txt', 'TEXT'),
             ('All Files', '*'),
         ]
         filename = filedialog.askopenfilename(filetypes=filetypes)
@@ -342,15 +389,15 @@ class Application:
 
     def callback_help_about(self):
         """Callback for Menu Help > About"""
-        def mouse_over(event):
+        def mouse_over(event):      # noqa
             url_lbl.config(font=url_lbl.default_font + ('underline',))
             url_lbl.config(cursor='hand2')
 
-        def mouse_out(event):
+        def mouse_out(event):       # noqa
             url_lbl.config(font=url_lbl.default_font)
             url_lbl.config(cursor='arrow')
 
-        def mouse_press(event):
+        def mouse_press(event):     # noqa
             self.browser.open_new_tab(url_lbl.link)
 
         is_macos = platform.system() == 'Darwin'
@@ -438,8 +485,7 @@ class Application:
 
         # arguments checkboxes
         lst = [
-            ['used_space', self.used_space_var, 0, 0],
-            ['ignore_case', self.ignore_case_var, 0, 1],
+            ['ignore_case', self.ignore_case_var, 0, 0],
             ['prepended_ws', self.prepended_ws_var, 1, 0],
             ['appended_ws', self.appended_ws_var, 1, 1]
         ]
@@ -630,7 +676,7 @@ class Application:
             var.set('')
             pattern_layout = PatternReference.get_pattern_layout(name)
             pattern_layout = pattern_layout.replace('name_placeholder', name)
-            new_content_ = '{}\n\n{}\n'.format(content_.strip(), pattern_layout)
+            new_content_ = '{}\n\n{}\n'.format(content_.strip(), pattern_layout).lstrip()
             node.delete("1.0", "end")
             node.insert(tk.INSERT, new_content_)
 
@@ -963,19 +1009,19 @@ class Application:
         #     )
 
         # radio buttons
-        self.line_radio_btn = ttk.Radiobutton(
+        self.line_radio_btn = tk.Radiobutton(
             self.entry_frame, text='line',
-            variable=self.radio_line_or_block_btn_var,
+            variable=self.radio_line_or_multiline_btn_var,
             value='line'
         )
         self.line_radio_btn.grid(row=0, column=0, padx=(4, 0))
 
-        self.block_radio_btn = ttk.Radiobutton(
-            self.entry_frame, text='block',
-            variable=self.radio_line_or_block_btn_var,
-            value='block'
+        self.multiline_radio_btn = tk.Radiobutton(
+            self.entry_frame, text='multiline',
+            variable=self.radio_line_or_multiline_btn_var,
+            value='multiline'
         )
-        self.block_radio_btn.grid(row=0, column=1, padx=2)
+        self.multiline_radio_btn.grid(row=0, column=1, padx=2)
 
         # open button
         open_file_btn = ttk.Button(self.entry_frame, text='Open',
